@@ -5,8 +5,8 @@
 ;; Author: Daniel Mendler <mail@daniel-mendler.de>
 ;; Maintainer: Daniel Mendler <mail@daniel-mendler.de>
 ;; Created: 2022
-;; Version: 1.5
-;; Package-Requires: ((emacs "28.1") (compat "30"))
+;; Version: 1.6
+;; Package-Requires: ((emacs "29.1") (compat "30"))
 ;; URL: https://github.com/minad/tempel
 ;; Keywords: abbrev, languages, tools, text
 
@@ -530,8 +530,7 @@ TEMPLATES must be a list in the form (modes plist . templates)."
     for m in modes thereis
     (or (eq m #'fundamental-mode)
         (derived-mode-p m)
-        (when-let (((eval-when-compile (> emacs-major-version 28)))
-                   (remap (alist-get m (bound-and-true-p major-mode-remap-alist))))
+        (when-let ((remap (alist-get m major-mode-remap-alist)))
           (derived-mode-p remap))))
    (or tempel--ignore-condition
        (not (plist-member plist :when))
@@ -735,7 +734,7 @@ Capf, otherwise like an interactive completion command."
     ;; If Tempel completion is invoked manually, use the marked region for
     ;; template insertion. Insert a trigger prefix if missing. Furthermore
     ;; accept empty input bounds.
-    (let* ((manually (memq this-command (list #'completion-at-point #'tempel-complete)))
+    (let* ((manually (eq this-command #'tempel-complete))
            (region (and manually (tempel--region))))
       (when (and manually tempel-trigger-prefix (not (tempel--prefix-bounds)))
         (insert tempel-trigger-prefix))
